pub(crate) fn all_edits_are_disjoint(
completion: &CompletionItem,
additional_edits: &[TextEdit],
) -> boolExpand description
Checks that the edits inside the completion and the additional edits do not overlap. LSP explicitly forbids the additional edits to overlap both with the main edit and themselves.